from .IRecipeBookResults import *

class MixinRecipeBookResults(Object, IRecipeBookResults):



    def __init__():
        pass


    def jsmacros_getResultCollections(self, ) -> list:
        pass


    pass
